Data Processing Algorithms
--------------------------
These figures and examples show some of the data processing and algorithmic
tools enabled by astroML and other Python packages. For more examples,
see the :ref:`figures <book_fig_root>` from the textbook.
